#############################################
@{{ program }}@ - analysis of MD flux results
#############################################

Initial flux report generated by @{{ program }}@ version @{{ version }}@
on @{{ date }}@.

The main results are the initial fluxes:

@{{ tables['md-flux'] }}@

Detailed results are given below and
the flux results are summarized in the
section on `MD flux data`_.

.. _md-flux-results:

Results from the MD flux analysis
=================================

.. _energy-figures-output:

MD energy data
--------------

Energy and the running average of the energy:

.. image:: @{{ figures['energy']['energies'] }}@
   :width: 45%
.. image:: @{{ figures['energy']['runenergies'] }}@
   :width: 45%

Temperature and the running average of the temperature:

.. image:: @{{ figures['energy']['temperature'] }}@
   :width: 45%
.. image:: @{{ figures['energy']['runtemperature'] }}@
   :width: 45%

Block error analysis for energies:

.. image:: @{{ figures['energy']['ekinblock'] }}@
   :width: 30%
.. image:: @{{ figures['energy']['vpotblock'] }}@
   :width: 30%
.. image:: @{{ figures['energy']['etotblock'] }}@
   :width: 30%

Distribution of energies:

.. image:: @{{ figures['energy']['ekindist'] }}@
   :width: 30%
.. image:: @{{ figures['energy']['vpotdist'] }}@
   :width: 30%
.. image:: @{{ figures['energy']['etotdist'] }}@
   :width: 30%

Block error and distribution for temperature:

.. image:: @{{ figures['energy']['tempblock'] }}@
   :width: 30%
.. image:: @{{ figures['energy']['tempdist'] }}@
   :width: 30%

.. _order-figures-output:

MD order parameter data
-----------------------

.. image:: @{{ figures['order']['order'] }}@
   :width: 30%
.. image:: @{{ figures['order']['runorder'] }}@
   :width: 30%
.. image:: @{{ figures['order']['ordererror'] }}@
   :width: 30%

.. image:: @{{ figures['order']['orderdist'] }}@
   :width: 30%
.. image:: @{{ figures['order']['ordermsd'] }}@
   :width: 30%
.. image:: @{{ figures['order']['orderv'] }}@
   :width: 30%


.. _flux-figures-output:

MD flux data
------------

@{% for figure in figures['flux'] %}@
.. image:: @{{ figure['runflux'] }}@
   :width: 45%
.. image:: @{{ figure['errflux'] }}@
   :width: 45%
@{% endfor %}@

@{{ tables['md-flux'] }}@

@{{ tables['md-cycles'] }}@

@{{ tables['md-efficiency'] }}@
